]> git.saurik.com Git - cydia.git/blobdiff - Cydia.mm
even more browserview/cydia; fully working now!
[cydia.git] / Cydia.mm
index 02c2ae9a178573cdbf526fe09ebafd82ed674460..f42afe3ecd8bdd5d50d44dabfe419fc6cd0335d9 100644 (file)
--- a/Cydia.mm
+++ b/Cydia.mm
@@ -5264,7 +5264,11 @@ bool DepSubstrate(const pkgCache::VerIterator &iterator) {
 }
 
 - (void) reloadButtonClicked {
-    // You don't reload a package view by clicking the button.
+    // Don't reload a package view by clicking the button.
+}
+
+- (void) applyLoadingTitle {
+    // Don't show "Loading" as the title. Ever.
 }
 #endif